# Copyright 2011 Kevin Ryde

# Generated by make-oeis-catalogue.pl -- DO NOT EDIT

# This file is part of Math-Image.
#
# Math-Image is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 3, or (at your option) any later
# version.
#
# Math-Image is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with Math-Image.  If not, see <http://www.gnu.org/licenses/>.

package App::MathImage::Values::OEIS::Catalogue::Plugin::Builtin;
use strict;
use warnings;

use vars '$VERSION';
$VERSION = 43;

use constant anum_to_class_hashref =>
{
  'A000027' => [
    'App::MathImage::Values::All'
  ],
  'A000040' => [
    'App::MathImage::Values::Primes'
  ],
  'A000045' => [
    'App::MathImage::Values::Fibonacci'
  ],
  'A000073' => [
    'App::MathImage::Values::Tribonacci'
  ],
  'A000129' => [
    'App::MathImage::Values::PellNumbers'
  ],
  'A000142' => [
    'App::MathImage::Values::Factorials'
  ],
  'A000201' => [
    'App::MathImage::Values::GoldenSequence'
  ],
  'A000204' => [
    'App::MathImage::Values::LucasNumbers'
  ],
  'A000217' => [
    'App::MathImage::Values::Polygonal',
    'polygonal',
    '3',
    'pairs',
    'first'
  ],
  'A000290' => [
    'App::MathImage::Values::Polygonal',
    'polygonal',
    '4',
    'pairs',
    'first'
  ],
  'A000292' => [
    'App::MathImage::Values::Tetrahedral'
  ],
  'A000326' => [
    'App::MathImage::Values::Polygonal',
    'polygonal',
    '5',
    'pairs',
    'first'
  ],
  'A000384' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A000566' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A000567' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A000578' => [
    'App::MathImage::Values::Cubes'
  ],
  'A000931' => [
    'App::MathImage::Values::Padovan'
  ],
  'A001097' => [
    'App::MathImage::Values::TwinPrimes',
    'pairs',
    'both'
  ],
  'A001106' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A001107' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A001222' => [
    'App::MathImage::Values::CountPrimeFactors'
  ],
  'A001318' => [
    'App::MathImage::Values::Polygonal',
    'polygonal',
    '5',
    'pairs',
    'both'
  ],
  'A001358' => [
    'App::MathImage::Values::SemiPrimes'
  ],
  'A001359' => [
    'App::MathImage::Values::TwinPrimes',
    'pairs',
    'first'
  ],
  'A001608' => [
    'App::MathImage::Values::Perrin'
  ],
  'A002113' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '10'
  ],
  'A002163' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '5',
    'radix',
    '10'
  ],
  'A002193' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '2',
    'radix',
    '10'
  ],
  'A002194' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '3',
    'radix',
    '10'
  ],
  'A002378' => [
    'App::MathImage::Values::Pronic'
  ],
  'A003154' => [
    'App::MathImage::Values::StarNumbers'
  ],
  'A004539' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '2',
    'radix',
    '2'
  ],
  'A004540' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '2',
    'radix',
    '3'
  ],
  'A004541' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '2',
    'radix',
    '4'
  ],
  'A004542' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '2',
    'radix',
    '5'
  ],
  'A005101' => [
    'App::MathImage::Values::AbundantNumbers'
  ],
  'A005384' => [
    'App::MathImage::Values::SophieGermainPrimes'
  ],
  'A005385' => [
    'App::MathImage::Values::SafePrimes'
  ],
  'A005408' => [
    'App::MathImage::Values::Odd'
  ],
  'A005449' => [
    'App::MathImage::Values::Polygonal',
    'polygonal',
    '5',
    'pairs',
    'second'
  ],
  'A005823' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '3',
    'digit',
    '1'
  ],
  'A005836' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '3',
    'digit',
    '2'
  ],
  'A005843' => [
    'App::MathImage::Values::Even'
  ],
  'A006512' => [
    'App::MathImage::Values::TwinPrimes',
    'pairs',
    'second'
  ],
  'A006567' => [
    'App::MathImage::Values::Emirps',
    'radix',
    '10'
  ],
  'A006995' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '2'
  ],
  'A010060' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '2'
  ],
  'A010467' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '10',
    'radix',
    '10'
  ],
  'A010468' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '11',
    'radix',
    '10'
  ],
  'A010469' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '12',
    'radix',
    '10'
  ],
  'A010470' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '13',
    'radix',
    '10'
  ],
  'A010471' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '14',
    'radix',
    '10'
  ],
  'A010472' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '15',
    'radix',
    '10'
  ],
  'A010473' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '17',
    'radix',
    '10'
  ],
  'A010474' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '18',
    'radix',
    '10'
  ],
  'A010475' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '19',
    'radix',
    '10'
  ],
  'A010476' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '20',
    'radix',
    '10'
  ],
  'A010477' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '21',
    'radix',
    '10'
  ],
  'A010478' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '22',
    'radix',
    '10'
  ],
  'A010479' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '23',
    'radix',
    '10'
  ],
  'A010480' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '24',
    'radix',
    '10'
  ],
  'A010481' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '26',
    'radix',
    '10'
  ],
  'A010482' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '27',
    'radix',
    '10'
  ],
  'A010483' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '28',
    'radix',
    '10'
  ],
  'A010484' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '29',
    'radix',
    '10'
  ],
  'A010485' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '30',
    'radix',
    '10'
  ],
  'A010486' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '31',
    'radix',
    '10'
  ],
  'A010487' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '32',
    'radix',
    '10'
  ],
  'A010488' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '33',
    'radix',
    '10'
  ],
  'A010489' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '34',
    'radix',
    '10'
  ],
  'A010490' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '35',
    'radix',
    '10'
  ],
  'A010491' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '37',
    'radix',
    '10'
  ],
  'A010492' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '38',
    'radix',
    '10'
  ],
  'A010493' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '39',
    'radix',
    '10'
  ],
  'A010494' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '40',
    'radix',
    '10'
  ],
  'A010495' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '41',
    'radix',
    '10'
  ],
  'A010496' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '42',
    'radix',
    '10'
  ],
  'A010497' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '43',
    'radix',
    '10'
  ],
  'A010498' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '44',
    'radix',
    '10'
  ],
  'A010499' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '45',
    'radix',
    '10'
  ],
  'A010500' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '46',
    'radix',
    '10'
  ],
  'A010501' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '47',
    'radix',
    '10'
  ],
  'A010502' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '48',
    'radix',
    '10'
  ],
  'A010503' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '50',
    'radix',
    '10'
  ],
  'A010504' => [
    'App::MathImage::Values::SqrtDigits',
    'sqrt',
    '51',
    'radix',
    '10'
  ],
  'A010785' => [
    'App::MathImage::Values::Repdigits',
    'radix',
    '10'
  ],
  'A014105' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'second'
  ],
  'A014190' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '3'
  ],
  'A014192' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '4'
  ],
  'A021739' => [
    'App::MathImage::Values::FractionDigits',
    'fraction',
    '1/735',
    'radix',
    '10'
  ],
  'A022155' => [
    'App::MathImage::Values::GolayRudinShapiro'
  ],
  'A023705' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '4',
    'digit',
    '0'
  ],
  'A023709' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '4',
    'digit',
    '1'
  ],
  'A023713' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '4',
    'digit',
    '2'
  ],
  'A023717' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '4',
    'digit',
    '3'
  ],
  'A023721' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '5',
    'digit',
    '0'
  ],
  'A023725' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '5',
    'digit',
    '1'
  ],
  'A023729' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '5',
    'digit',
    '2'
  ],
  'A023733' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '5',
    'digit',
    '4'
  ],
  'A023737' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '5',
    'digit',
    '5'
  ],
  'A029803' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '8'
  ],
  'A029953' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '6'
  ],
  'A029954' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '7'
  ],
  'A029955' => [
    'App::MathImage::Values::Palindromes',
    'radix',
    '9'
  ],
  'A030303' => [
    'App::MathImage::Values::ChampernowneBinary'
  ],
  'A032924' => [
    'App::MathImage::Values::RadixWithoutDigit',
    'radix',
    '3',
    'digit',
    '0'
  ],
  'A051003' => [
    'App::MathImage::Values::Beastly',
    'radix',
    '10'
  ],
  'A051624' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051682' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051865' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051866' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051867' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051868' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051869' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051870' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051871' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051872' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051873' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051874' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051875' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A051876' => [
    'App::MathImage::Values::Polygonal',
    'pairs',
    'first'
  ],
  'A053696' => [
    'App::MathImage::Values::RepdigitAnyBase'
  ],
  'A053838' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '3'
  ],
  'A053839' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '4'
  ],
  'A053840' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '5'
  ],
  'A053841' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '6'
  ],
  'A053842' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '7'
  ],
  'A053843' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '8'
  ],
  'A053844' => [
    'App::MathImage::Values::DigitsModulo',
    'radix',
    '9'
  ],
  'A079000' => [
    'App::MathImage::Values::NumaronsonA'
  ],
  'A083652' => [
    'App::MathImage::Values::BinaryLengths'
  ],
  'A133122' => [
    'App::MathImage::Values::ObstinateNumbers'
  ]
}
;
1;
__END__
